From 6a7feea45569b15bc0560f74cf27dbc3abd37ffd Mon Sep 17 00:00:00 2001
From: david-sarah <david-sarah@jacaranda.org>
Date: Tue, 23 Feb 2010 19:02:31 -0800
Subject: [PATCH] Tweak to 'tahoe ls --help' output (#837)

---
 src/allmydata/scripts/cli.py | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)

diff --git a/src/allmydata/scripts/cli.py b/src/allmydata/scripts/cli.py
index c2efe9d3..890ece56 100644
--- a/src/allmydata/scripts/cli.py
+++ b/src/allmydata/scripts/cli.py
@@ -97,7 +97,9 @@ class ListOptions(VDriveOptions):
     If 'd' is present, it indicates that the object is a directory.
     If the 'd' is replaced by a '?', the object type is unknown.
     'rwx' is a Unix-like permissions mask: if the mask includes 'w',
-    then the object is writable through its link in this directory.
+    then the object is writeable through its link in this directory
+    (note that the link might be replaceable even if the object is
+    not writeable through the current link).
     The 'x' is a legacy of Unix filesystems. In Tahoe it is used
     only to indicate that the contents of a directory can be listed.
 
-- 
2.45.2